@@ -30,23 +30,16 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 
-enum DataModes {
-    CopyData, AppendData
-};
-
-enum DataTypes {
-    SingleVector = 1, TwinVectors = 2
-};
 
 /*
- * Sun's bundled and unbundled C compilers can't grok static
- * function typedefs (it can handle extern) like
+ * Sun's bundled and unbundled C compilers can't grok static function
+ * typedefs (it can handle extern) like
  *
  * 	static Tk_OptionParseProc parseProc;
  *  	static Tk_OptionPrintProc printProc;
  *
- * Provide forward declarations here:
- */
+ * Provide forward declarations here: 
+*/
 static int ParseSymbolType _ANSI_ARGS_((ClientData clientData,
 	Tcl_Interp *interp, Tk_Window tkwin, char *value, char *widgRec,
 	int offset));
@@ -75,17 +68,24 @@ extern char *Blt_PrintAxisFlags _ANSI_ARGS_((ClientData, Tk_Window, char *, int,
 	Tcl_FreeProc **));
 
 #include "bltGrElem.h"
+				
+#define DEF_VECTOR_SIZE	32	  /* Starting size of a data vector. */
+enum DataModes {
+    CopyData, AppendData
+};
+enum DataTypes {
+    SingleVector = 1, TwinVectors = 2
+};
 
 /*
- * Element attributes: either symbol types or line styles
- */
+ * Element attributes: either symbol types or line styles 
+*/
 static char *lineSymbolNames[] =
 {
     "Line", "Square", "Circle", "Diamond", "Plus", "Cross", "Splus", "Scross",
 };
 static int numSymbols = sizeof(lineSymbolNames) / sizeof(char *);
 
-
 typedef struct {
     SymbolType type;
     Display *display;		/* Display on which to draw symbol */
@@ -105,21 +105,23 @@ typedef struct {
     int numPoints;		/* Number of points in segment */
 } LineInfo;
 
-
 typedef struct {
-    Tcl_Interp *interp;		/* Interpreter of the graph widget. This is
-				 * only needed for Tcl_PrintDouble calls in
-				 * the custom configure print routines. */
+    Tcl_Interp *interp;		/* Interpreter of the graph widget.
+				 * This is only needed for
+				 * Tcl_PrintDouble calls in the custom
+				 * configure print routines. */
     ElementClassType type;	/* Type of element is LINE_ELEMENT */
     unsigned int flags;
-    Tk_Uid id;			/* Identifier to refer the element. Used in
-				 * the "insert", "delete", or "show",
-				 * commands. */
-    int mapped;			/* If non-zero, element is currently visible.*/
+    Tk_Uid id;			/* Identifier to refer the element.
+				 * Used in the "insert", "delete", or
+				 * "show", commands. */
+    int mapped;			/* If non-zero, element is currently
+				 * visible.*/
     Tk_ConfigSpec *configSpecs;	/* Configuration specifications */
     char *label;		/* Label displayed in legend */
     SymbolType symbol;		/* Element symbol type */
-    double symbolScale;		/* Scale factor when computing symbol size */
+    double symbolScale;		/* Scale factor when computing symbol
+				 * size */
     int symbolSize;		/* Computed size of symbol in pixels. */
     Vector x, y;		/* Contains array of numeric values */
     unsigned int axisFlags;	/* Indicates which axes to map element's
@@ -137,11 +139,13 @@ typedef struct {
     /*
      * Line specific configurable attributes
      */
-    int active;			/* If non-zero, indicates element is active.
-				 * Active indicates which color/GCs to use
-				 * when displaying the element's data points */
-    int *activePoints;		/* Array of indices of active data points. If
-				 * NULL, all data points are active */
+    int active;			/* If non-zero, indicates element is
+				 * active.  Active indicates which
+				 * color/GCs to use when displaying
+				 * the element's data points */
+    int *activePoints;		/* Array of indices of active data
+				 * points. If NULL, all data points
+				 * are active */
     int numActivePoints;
 
     XColor *normalFg;		/* normal color of lines/borders*/
@@ -151,9 +155,9 @@ typedef struct {
 
     int lineWidth;		/* Line width */
     int dashes;			/* Dash on-off list value */
-    int noretrace;		/* If non-zero, break connected line segments
-				 * where x-coordinate values are not
-				 * monotonically increasing. */
+    int noretrace;		/* If non-zero, break connected line
+				 * segments where x-coordinate values
+				 * are not monotonically increasing. */
     GC normalBorderGC;		/* Symbol border graphics context */
     GC normalFillGC;		/* Symbol fill graphics context */
     GC normalLineGC;		/* Line graphics context */
@@ -164,13 +168,14 @@ typedef struct {
     /*
      * Drawing related structures
      */
-    XPoint *pointArr;		/* Array of window coordinates representing
-				 * the points of the line (malloc'ed) */
+    XPoint *pointArr;		/* Array of window coordinates
+				 * representing the points of the line
+				 * (malloc'ed) */
     int numPoints;		/* Number of points in point array */
-
     LineInfo *segArr;		/* Array of line segment information
 				 * (malloc'ed) */
-    int numSegments;		/* Number of line segments in point array */
+    int numSegments;		/* Number of line segments in point
+				 * array */
 
 } LineElement;
 
@@ -194,7 +199,6 @@ static Tk_CustomOption TwinOption =
 };
 
 static Tk_CustomOption ColorListOption =
-
 {
     ParseColorList, PrintColorList, (ClientData)0
 };
@@ -218,7 +222,8 @@ static Tk_CustomOption YAxisFlagsOption =
 #define DEF_ELEM_ACTIVE_BG_MONO	BLACK
 #define DEF_ELEM_ACTIVE_FG_MONO WHITE
 #define DEF_ELEM_BORDERWIDTH	"2"
-#define DEF_ELEM_AXIS		"y"
+#define DEF_ELEM_X_AXIS		"x"
+#define DEF_ELEM_Y_AXIS		"y"
 
 static Tk_ConfigSpec lineConfigSpecs[] =
 {
@@ -263,10 +268,10 @@ static Tk_ConfigSpec lineConfigSpecs[] =
     {TK_CONFIG_PIXELS, "-linewidth", "lineElemLinewidth", "ElemLinewidth",
 	(char *)NULL, Tk_Offset(LineElement, lineWidth), 0},
     {TK_CONFIG_CUSTOM, "-mapx", "lineElemMapX", "ElemMapX",
-	DEF_ELEM_AXIS, Tk_Offset(LineElement, axisFlags),
+	DEF_ELEM_X_AXIS, Tk_Offset(LineElement, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &XAxisFlagsOption},
     {TK_CONFIG_CUSTOM, "-mapy", "lineElemMapY", "ElemMapY",
-	DEF_ELEM_AXIS, Tk_Offset(LineElement, axisFlags),
+	DEF_ELEM_Y_AXIS, Tk_Offset(LineElement, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &YAxisFlagsOption},
     {TK_CONFIG_DOUBLE, "-scale", "lineElemScale", "ElemScale",
 	(char *)NULL, Tk_Offset(LineElement, symbolScale), 0},
@@ -287,19 +292,20 @@ typedef struct {
     Tcl_Interp *interp;		/* Interpreter of the graph widget */
     ElementClassType type;	/* Type of element is BAR_ELEMENT */
     unsigned int flags;
-    Tk_Uid id;			/* Identifier to refer the element. Used in
-				 * the "insert", "delete", or "show",
-				 * commands. */
-    int mapped;			/* If non-zero, element is currently visible.*/
+    Tk_Uid id;			/* Identifier to refer the element.
+				 * Used in the "insert", "delete", or
+				 * "show", commands. */
+    int mapped;			/* If non-zero, element is currently
+				 * visible.*/
     Tk_ConfigSpec *configSpecs;	/* Configuration specifications */
     char *label;		/* Label displayed in legend */
     SymbolType symbol;		/* Element symbol type */
-    double symbolScale;		/* Size of symbol as a percentage of the
-				 * drawing area. */
+    double symbolScale;		/* Size of symbol as a percentage of
+				 * the drawing area. */
     int symbolSize;		/* Computed size of symbol in pixels. */
     Vector x, y;		/* Contains array of numeric values */
-    unsigned int axisFlags;	/* Indicates which axes to map element's
-				 * coordinates onto */
+    unsigned int axisFlags;	/* Indicates which axes to map
+				 * element's coordinates onto */
 
     ElemConfigProc *configProc;
     ElemDestroyProc *destroyProc;
@@ -318,15 +324,19 @@ typedef struct {
     int relief;			/* Relief of bar */
     XColor **fgColorArr;	/* Array of colors  */
     int numFgColors;		/* Number of colors in color array */
-    GC *gcArr;			/* Array of shared Graphics Context pointers */
+    GC *gcArr;			/* Array of shared Graphics Context
+				 * pointers */
     int numGCs;			/* Number of GC's in array */
-    int stacked;		/* If non-zero, the set of bar y-values
-				 * represent a stacked bar segments */
-    Pixmap stipple;		/* Bitmap representing stippled pattern of
-				 * bar. If None, indicates a solid fill. */
+    int stacked;		/* If non-zero, the bar y-values
+				 * represent a set of stacked bar
+				 * segments */
+    Pixmap stipple;		/* Bitmap representing stippled
+				 * pattern of bar. If None, indicates
+				 * a solid fill. */
     int padX;			/* Spacing on either side of bar */
-    XRectangle *rectArr;	/* Array of rectangle coordinates composing
-				 * the set of a bars possible */
+    XRectangle *rectArr;	/* Array of rectangle coordinates
+				 * composing the set of a bars
+				 * possible */
     int numRects;		/* Number of bars in the set */
 
 } BarElement;
@@ -359,10 +369,10 @@ static Tk_ConfigSpec barConfigSpecs[] =
     {TK_CONFIG_STRING, "-label", "barElemLabel", "ElemLabel",
 	(char *)NULL, Tk_Offset(BarElement, label), TK_CONFIG_NULL_OK},
     {TK_CONFIG_CUSTOM, "-mapx", "barElemMapX", "ElemMapX",
-	DEF_ELEM_AXIS, Tk_Offset(BarElement, axisFlags),
+	DEF_ELEM_X_AXIS, Tk_Offset(BarElement, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &XAxisFlagsOption},
     {TK_CONFIG_CUSTOM, "-mapy", "barElemMapY", "ElemMapY",
-	DEF_ELEM_AXIS, Tk_Offset(BarElement, axisFlags),
+	DEF_ELEM_Y_AXIS, Tk_Offset(BarElement, axisFlags),
 	TK_CONFIG_DONT_SET_DEFAULT, &YAxisFlagsOption},
     {TK_CONFIG_RELIEF, "-relief", "barElemRelief", "ElemRelief",
 	(char *)NULL, Tk_Offset(BarElement, relief), 0},
@@ -378,7 +388,6 @@ static Tk_ConfigSpec barConfigSpecs[] =
 };
 
 /* Forward declarations */
-
 extern int Blt_OptionChanged _ANSI_ARGS_((Tk_ConfigSpec *, int *, int));
 extern int strncasecmp _ANSI_ARGS_((CONST char *s1, CONST char *s2, size_t n));
 
@@ -386,7 +395,6 @@ extern int strncasecmp _ANSI_ARGS_((CONST char *s1, CONST char *s2, size_t n));
  * Custom option parse and print procedures
  * ----------------------------------------------------------------------
  */
-
 /*
  *----------------------------------------------------------------------
  *
@@ -520,9 +528,7 @@ ParseColorList(clientData, interp, tkwin, value, widgRec, offset)
     }
     free((char *)colorNames);
 
-    /*
-     * Release color resources from the old color list
-     */
+    /*  Release color resources from the old color list */
     for (i = 0; i < barElemPtr->numFgColors; i++) {
 	colorPtr = barElemPtr->fgColorArr[i];
 	Tk_FreeColor(colorPtr);
@@ -613,8 +619,8 @@ ConvertExpressions(interp, exprArr, numExpr, dataArr, start, step)
     double x;
 
     /*
-     * Parse and evaluate the list of numeric expressions into an array of
-     * floating point numbers.
+     * Parse and evaluate the list of numeric expressions into an
+     * array of floating point numbers. 
      */
     for (count = 0, i = start; i < numExpr; i += step, count++) {
 	if (Tcl_ExprDouble(interp, exprArr[i], &x) != TCL_OK) {
@@ -648,8 +654,9 @@ GetDataLimits(vecPtr)
 {
     register int i;
 
-    /*
-     * Find the minimum, positive minimum, and maximum values in the array.
+    /* 
+     * Find the minimum, positive minimum, and maximum values in the
+     * array. 
      */
     vecPtr->min = vecPtr->max = vecPtr->data[0];
     vecPtr->logMin = Blt_posInfinity;
@@ -710,11 +717,12 @@ AppendVector(interp, vecPtr, exprArr, numExpr, start, type, mode)
     needed = (numExpr / step) + offset;
 
     /*
-     * Keep doubling the size of the array until we fit the number needed
+     * Keep doubling the size of the array until we fit the number
+     * needed 
      */
     arraySize = vecPtr->size;
     if (arraySize == 0) {
-	arraySize = 32;
+	arraySize = DEF_VECTOR_SIZE;
     }
     while (needed > arraySize) {
 	arraySize += arraySize;
@@ -784,7 +792,7 @@ ParseVector(clientData, interp, tkwin, value, widgRec, offset)
 	return TCL_ERROR;
     }
     if (numExprs >= 65535) {
-	interp->result = "Vector is too large";	/* XDrawLines limit */
+	interp->result = "vector is too large";	/* XDrawLines limit */
 	goto error;
     }
     if (AppendVector(interp, vecPtr, exprArr, numExprs, 0, SingleVector,
@@ -882,10 +890,10 @@ ParseCoordPairs(clientData, interp, tkwin, value, widgRec, offset)
 	return TCL_ERROR;
     }
     if (numExprs >= 131070) {
-	interp->result = "Vector is too large";	/* XDrawLines limit */
+	interp->result = "vector is too large";	/* XDrawLines limit */
 	goto error;
     } else if (numExprs & 1) {
-	interp->result = "Odd number of values in -xydata option";
+	interp->result = "odd number of values in -xydata option";
 	goto error;
     }
     if (AppendVector(interp, &(elemPtr->x), exprArr, numExprs, 0,
@@ -984,9 +992,8 @@ ConfigureLine(graphPtr, elemPtr)
     GC newGC;
     XGCValues gcValues;
 
-    /*
-     * Borders of symbols: need foreground only
-     */
+    /* Borders of symbols: need foreground only */
+
     gcValues.foreground = lineElemPtr->normalFg->pixel;
     newGC = Tk_GetGC(graphPtr->tkwin, GCForeground, &gcValues);
     if (lineElemPtr->normalBorderGC != NULL) {
@@ -1001,9 +1008,8 @@ ConfigureLine(graphPtr, elemPtr)
     }
     lineElemPtr->activeBorderGC = newGC;
 
-    /*
-     * Fills for symbols: need reversed foreground and background
-     */
+    /* Fills for symbols: need reversed foreground and background */
+
     gcMask = (GCBackground | GCForeground);
     gcValues.background = lineElemPtr->normalFg->pixel;
     gcValues.foreground = lineElemPtr->normalBg->pixel;
@@ -1020,9 +1026,9 @@ ConfigureLine(graphPtr, elemPtr)
 	Tk_FreeGC(graphPtr->display, lineElemPtr->activeFillGC);
     }
     lineElemPtr->activeFillGC = newGC;
-    /*
-     * Lines
-     */
+
+    /* Lines */
+
     gcMask |= (GCLineWidth | GCLineStyle | GCCapStyle | GCJoinStyle);
     gcValues.cap_style = CapButt;
     gcValues.join_style = JoinRound;
@@ -1103,10 +1109,10 @@ GetLineLimits(elemPtr, axisPtr, minPtr, maxPtr)
  *	the window coordinates point specified.
  *
  * Results:
- *	Returns the index of the closest point.  In addition, distPtr is
- *	set to distance (squared) between the found coordinate and the
- *	given point.  Returns -1 if the point does not fail within the
- *	range prescribed.
+ *	Returns the distance of the closest point.  In addition, 
+ *	indexPtr is set to position of coordinate and the list of data 
+ *	points.  Index is -1 if the point does not fail within the 
+ *	prescribed range.
  *
  *----------------------------------------------------------------------
  */
@@ -1197,19 +1203,17 @@ LayoutLine(graphPtr, elemPtr)
     /*
      * We need to determine is line segments exist only if
      *
-     *	  1) retracing is not allowed, and
-     *
-     *    2) we need to draw element lines (either because the symbol
-     *	     type is "line" or the line width is greater than zero, which
-     *	     means to add a line in addition to the symbol).
+     * 1) retracing is not allowed, and
      *
+     * 2) we need to draw element lines (either because the symbol
+     *    type is "line" or the line width is greater than zero,
+     *	  which means to add a line in addition to the symbol).
      */
     needSegments = ((lineElemPtr->noretrace) && ((lineElemPtr->lineWidth > 0)
 	    || (lineElemPtr->symbol == LINE_SYMBOL)));
-
     /*
-     * Transform and store the coordinates into an array window points.
-     * In addition, make a quick count of line segments.
+     * Transform and store the coordinates into an array window
+     * points.  In addition, make a quick count of line segments. 
      */
     lastX = 0;			/* suppress compiler warning */
     total = numSegments = 0;
@@ -1268,9 +1272,7 @@ LayoutLine(graphPtr, elemPtr)
     lineElemPtr->segArr = segArr;
     lineElemPtr->numSegments = numSegments;
 
-    /*
-     * Make the symbol size odd so that its center is a single pixel.
-     */
+    /* Make the symbol size odd so that its center is a single pixel. */
     lineElemPtr->symbolSize |= 0x01;
     lineElemPtr->symbolSize =
 	ROUND(graphPtr->avgSymSize * lineElemPtr->symbolScale);
@@ -1346,9 +1348,7 @@ GetSymbolInfo(graphPtr, lineElemPtr, size, active)
 	    register int i;
 	    register double dx, dy;
 
-	    /*
-	     * For the cross symbol, rotate the points by 45 degrees.
-	     */
+	    /* For the cross symbol, rotate the points by 45 degrees. */
 	    for (i = 0; i < 12; i++) {
 		dx = (double)(s.offset[i].x) * M_SQRT1_2;
 		dy = (double)(s.offset[i].y) * M_SQRT1_2;
@@ -1406,6 +1406,9 @@ GetSymbolInfo(graphPtr, lineElemPtr, size, active)
     case CIRCLE_SYMBOL:
 	s.size--;
 	break;
+
+    case LINE_SYMBOL:
+	break;
     }
 
     /* Set the correct GCs, depending if the element is active  */
@@ -1446,8 +1449,8 @@ DrawLineSymbol(x, y, infoPtr)
     switch (infoPtr->type) {
     case LINE_SYMBOL:
 	/*
-	 * Draw an extra line offset by one pixel from the previous
-	 * to give a thicker appearance
+	 * Draw an extra line offset by one pixel from the previous to
+	 * give a thicker appearance 
 	 */
 	XDrawLine(infoPtr->display, infoPtr->canvas, infoPtr->lineGC,
 	    x - infoPtr->radius, y, x + infoPtr->radius, y);
@@ -2368,7 +2371,6 @@ CreateBar()
     register BarElement *barElemPtr;
 
     barElemPtr = (BarElement *)calloc(1, sizeof(BarElement));
-
     if (barElemPtr == NULL) {
 	return NULL;
     }
@@ -2626,6 +2628,7 @@ AppendElement(graphPtr, argc, argv)
 	goto error;
     }
     result = TCL_OK;
+    elemPtr->flags |= LAYOUT_PENDING; /* Re-generate screen points */
     Blt_ComputeAxes(graphPtr);
     Blt_EventuallyRedraw(graphPtr);
   error:
@@ -2778,9 +2781,7 @@ ResetDisplayList(graphPtr, newList)
 	    "\"", (char *)NULL);
 	return TCL_ERROR;
     }
-    /*
-     * Clear the display list and mark all elements unmapped.
-     */
+    /* Clear the display list and mark all elements unmapped. */
     Blt_ClearList(&(graphPtr->elemList));
     for (hashPtr = Tcl_FirstHashEntry(&(graphPtr->elemTable), &cursor);
 	hashPtr != NULL; hashPtr = Tcl_NextHashEntry(&cursor)) {
@@ -2790,7 +2791,7 @@ ResetDisplayList(graphPtr, newList)
 
     /*
      * Rebuild the display list, checking that each name it exists
-     * (we're currently ignoring invalid element names).
+     * (we're currently ignoring invalid element names). 
      */
     for (count = 0; count < numNames; count++) {
 	hashPtr = Tcl_FindHashEntry(&(graphPtr->elemTable), nameArr[count]);
@@ -2904,9 +2905,8 @@ ClosestElement(graphPtr, argc, argv)
 	int index;
 	register int i;
 
-	/*
-	 * Search for closest point in set of elements listed
-	 */
+	/* Search for closest point in set of elements listed */
+
 	for (i = 5; i < argc; i++) {	/* Element name list supplied */
 	    entryPtr = Tcl_FindHashEntry(&(graphPtr->elemTable), argv[i]);
 	    if (entryPtr == NULL) {
@@ -2932,9 +2932,8 @@ ClosestElement(graphPtr, argc, argv)
 	double dist;
 	int index;
 
-	/*
-	 * Search for closest point in set of displayed elements
-	 */
+	/* Search for closest point in set of displayed elements */
+
 	for (entryPtr = Blt_FirstListEntry(&(graphPtr->elemList));
 	    entryPtr != NULL; entryPtr = Blt_NextListEntry(entryPtr)) {
 	    elemPtr = (Element *)Blt_GetListValue(entryPtr);
@@ -3147,11 +3146,12 @@ UpdateVector(graphPtr, vecPtr, start, numValues, valueArr)
     needed = (numValues / 2) + offset;
 
     /*
-     * Keep doubling the size of the array until we fit the number needed
+     * Keep doubling the size of the array until we fit the number
+     * needed 
      */
     arraySize = vecPtr->size;
     if (arraySize == 0) {
-	arraySize = 32;
+	arraySize = DEF_VECTOR_SIZE;
     }
     while (needed > arraySize) {
 	arraySize += arraySize;
@@ -3165,7 +3165,8 @@ UpdateVector(graphPtr, vecPtr, start, numValues, valueArr)
 	memcpy((char *)newArr, (char *)vecPtr->data, offset * sizeof(double));
     }
     /*
-     * Pick out every other value and stuff it into the extended array.
+     * Pick out every other value and stuff it into the extended
+     * array. 
      */
     for (i = start; i < numValues; i += 2) {
 	newArr[offset++] = valueArr[i];
