@@ -4,7 +4,7 @@
  *      This module implements a graph widget for
  *      the Tk toolkit.
  *
- * Copyright 1991-1993 by AT&T Bell Laboratories.
+ * Copyright 1991-1994 by AT&T Bell Laboratories.
  * Permission to use, copy, modify, and distribute this software
  * and its documentation for any purpose and without fee is hereby
  * granted, provided that the above copyright notice appear in all
@@ -43,6 +43,8 @@
 #define GREEN(c)        ((double)(c)->green/65536.0)
 #define BLUE(c)         ((double)(c)->blue/65536.0)
 
+#define PSMAXPATH	1450	/* Max length of a PS path */
+
 #define SET_BG_COLOR 	0
 #define SET_FG_COLOR	1
 
@@ -50,7 +52,10 @@ typedef enum ColorLevels {
     MONOCHROME_LEVEL, GRAYSCALE_LEVEL, FULLCOLOR_LEVEL
 } ColorLevel;
 
-static char *colorModes[] = {"monochrome", "grayscale", "color"};
+static char *colorModes[] =
+{
+    "monochrome", "grayscale", "color"
+};
 static int numColorModes = sizeof(colorModes) / sizeof(char *);
 
 /*
@@ -182,7 +187,7 @@ ParseColorMode(clientData, interp, tkwin, value, widgRec, offset)
     c = *value;
     length = strlen(value);
     for (i = 0; i < numColorModes; i++) {
-	if ((c == colorModes[i][0]) && 
+	if ((c == colorModes[i][0]) &&
 	    (strncmp(value, colorModes[i], length) == 0)) {
 	    *colorLevel = (ColorLevel)i;
 	    return TCL_OK;
@@ -305,7 +310,7 @@ static void
 XBitmapToPostScript(graphPtr, bitmap, width, height)
     Graph *graphPtr;
     Pixmap bitmap;
-    int width, height;
+    unsigned int width, height;
 {
     register unsigned int byte = 0;
     register int x, y, bitPos;
@@ -520,7 +525,7 @@ Blt_RectangleToPostScript(graphPtr, x, y, width, height)
     int x, y;
     unsigned int width, height;
 {
-    sprintf(graphPtr->scratchPtr, "%d %d %d %d Box Fill\n", x, y, width, 
+    sprintf(graphPtr->scratchPtr, "%d %d %d %d Box Fill\n", x, y, width,
 	height);
     Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
 }
@@ -584,9 +589,9 @@ Blt_RectanglesToPostScript(graphPtr, rectArr, numRects)
     }
 }
 
-/* 
- * The Border structure used internally by the Tk_3D* routines.  
- * The following is a copy of it from tk3d.c. 
+/*
+ * The Border structure used internally by the Tk_3D* routines.
+ * The following is a copy of it from tk3d.c.
  */
 typedef struct {
     Display *display;		/* Display for which the resources below are
@@ -617,8 +622,8 @@ Blt_Print3DRectangle(graphPtr, border, x, y, width, height, borderWidth,
     relief)
     Graph *graphPtr;		/* File pointer to write PS output. */
     Tk_3DBorder border;		/* Token for border to draw. */
-    int x, y, width, height;	/* Outside area of region in which border
-                                 * will be drawn. */
+    int x, y;			/* Coordinates of rectangle */
+    unsigned int width, height;	/* Region to be drawn. */
     int borderWidth;		/* Desired width for border, in pixels. */
     int relief;			/* Should be either TK_RELIEF_RAISED or
                                  * TK_RELIEF_SUNKEN;  indicates position of
@@ -663,17 +668,17 @@ Blt_Print3DRectangle(graphPtr, border, x, y, width, height, borderWidth,
 
     if ((relief == TK_RELIEF_GROOVE) || (relief == TK_RELIEF_RIDGE)) {
 	int halfWidth, insideOffset;
-	
-	halfWidth = borderWidth/2;
+
+	halfWidth = borderWidth / 2;
 	insideOffset = borderWidth - halfWidth;
 	Blt_Print3DRectangle(graphPtr, border, x, y, width, height, halfWidth,
-		(relief == TK_RELIEF_GROOVE) ? TK_RELIEF_SUNKEN : 
-		TK_RELIEF_RAISED);
+	    (relief == TK_RELIEF_GROOVE) ? TK_RELIEF_SUNKEN :
+	    TK_RELIEF_RAISED);
 	Blt_Print3DRectangle(graphPtr, border, x + insideOffset,
-		 y + insideOffset, width - insideOffset*2,
-		 height - insideOffset*2, halfWidth, 
-		(relief == TK_RELIEF_GROOVE) ? TK_RELIEF_RAISED : 
-		TK_RELIEF_SUNKEN);
+	    y + insideOffset, width - insideOffset * 2,
+	    height - insideOffset * 2, halfWidth,
+	    (relief == TK_RELIEF_GROOVE) ? TK_RELIEF_RAISED :
+	    TK_RELIEF_SUNKEN);
 	return;
     }
     if (relief == TK_RELIEF_RAISED) {
@@ -687,7 +692,7 @@ Blt_Print3DRectangle(graphPtr, border, x, y, width, height, borderWidth,
     }
     Blt_BackgroundToPostScript(graphPtr, bottom);
     Blt_RectangleToPostScript(graphPtr, x, y + height - borderWidth,
-	(unsigned int)width, (unsigned int)borderWidth);
+	width, (unsigned int)borderWidth);
     Blt_RectangleToPostScript(graphPtr, x + width - borderWidth, y,
 	(unsigned int)borderWidth, (unsigned int)height);
     points[0].x = points[1].x = points[6].x = x;
@@ -709,8 +714,8 @@ Blt_3DRectangleToPostScript(graphPtr, border, x, y, width, height,
     borderWidth, relief)
     Graph *graphPtr;
     Tk_3DBorder border;		/* Token for border to draw. */
-    int x, y, width, height;	/* Outside area of region in which border
-                                 * will be drawn. */
+    int x, y;			/* Coordinates of top-left of border area */
+    unsigned int width, height;	/* Dimension of border to be drawn. */
     int borderWidth;		/* Desired width for border, in pixels. */
     int relief;			/* Should be either TK_RELIEF_RAISED or
                                  * TK_RELIEF_SUNKEN;  indicates position of
@@ -719,9 +724,9 @@ Blt_3DRectangleToPostScript(graphPtr, border, x, y, width, height,
     Border *borderPtr = (Border *) border;
 
     /*
-     * I'm assuming that the rectangle is to be drawn as a background.  
-     * Setting the pen color as a foreground or background, only affects 
-     * the plot when the colormode option is "monochrome". 
+     * I'm assuming that the rectangle is to be drawn as a background.
+     * Setting the pen color as a foreground or background, only affects
+     * the plot when the colormode option is "monochrome".
      */
     Blt_BackgroundToPostScript(graphPtr, borderPtr->bgColorPtr);
     Blt_RectangleToPostScript(graphPtr, x, y, width, height);
@@ -749,7 +754,7 @@ Blt_BitmapToPostScript(graphPtr, bitmap, centerX, centerY,
     Graph *graphPtr;
     Pixmap bitmap;		/* Bitmap to be converted to PostScript */
     int centerX, centerY;	/* Bitmap's center coordinates */
-    int width, height;		/* Extents of bitmap */
+    unsigned int width, height;	/* Extents of bitmap */
     double theta;		/* Degrees to rotate bitmap */
     XColor *bgColorPtr;		/* Background color of bitmap: NULL indicates
 				 * no background color */
@@ -761,7 +766,7 @@ Blt_BitmapToPostScript(graphPtr, bitmap, centerX, centerY,
     } else {
 	Tcl_AppendResult(graphPtr->interp, "false ", (char *)NULL);
     }
-    sprintf(graphPtr->scratchPtr, "%d %d %d %d %g\n", centerX, centerY, 
+    sprintf(graphPtr->scratchPtr, "%d %d %d %d %g\n", centerX, centerY,
 	width, height, theta);
     Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
     XBitmapToPostScript(graphPtr, bitmap, width, height);
@@ -876,10 +881,10 @@ Blt_TextToPostScript(graphPtr, text, attrPtr, x, y)
 				 * font, background color, anchor */
     int x, y;			/* Window coordinates of anchor */
 {
-    int width, height;		/* Width and height of unrotated text */
+    unsigned int width, height;	/* Width and height of unrotated text */
     XPoint upperLeft;		/* Point in upperleft corner of rotated box */
     double centerX, centerY;
-    int rotWidth, rotHeight;
+    unsigned int rotWidth, rotHeight;
 
     if ((text == NULL) || (*text == '\0')) {
 	return;
@@ -895,6 +900,10 @@ Blt_TextToPostScript(graphPtr, text, attrPtr, x, y)
 	attrPtr->anchor);
     centerX = upperLeft.x + (rotWidth * 0.5);
     centerY = upperLeft.y + (rotHeight * 0.5);
+
+    Blt_FontToPostScript(graphPtr, attrPtr->fontPtr);
+    Blt_ForegroundToPostScript(graphPtr, attrPtr->fgColorPtr);
+
     if (attrPtr->bgColorPtr == (XColor *)NULL) {
 	Tcl_AppendResult(graphPtr->interp, "false ", (char *)NULL);
     } else {
@@ -908,8 +917,55 @@ Blt_TextToPostScript(graphPtr, text, attrPtr, x, y)
     Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
 }
 
+/*
+ * -----------------------------------------------------------------
+ *
+ * Blt_PrintLine --
+ *
+ *      Outputs PostScript commands to print a multi-segmented line.
+ *	It assumes a procedure DashesProc was previously defined.
+ *
+ * Results:
+ *      None.
+ *
+ * Side Effects:
+ *      Line is printed.
+
+ * -----------------------------------------------------------------
+ */
+
+void
+Blt_PrintLine(graphPtr, pointArr, numPoints)
+    Graph *graphPtr;
+    XPoint *pointArr;
+    int numPoints;
+{
+    register int i;
+
+    if (numPoints <= 0) {
+	return;
+    }
+    sprintf(graphPtr->scratchPtr, "newpath %d %d moveto\n", pointArr[0].x,
+	pointArr[0].y);
+    Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
+    for (i = 1; i < (numPoints - 1); i++) {
+	if (i % PSMAXPATH) {
+	    sprintf(graphPtr->scratchPtr, "%d %d lineto\n",
+		pointArr[i].x, pointArr[i].y);
+	} else {
+	    sprintf(graphPtr->scratchPtr,
+		"%d %d lineto\nDashesProc stroke\n\newpath %d %d moveto\n",
+		pointArr[i].x, pointArr[i].y, pointArr[i].x, pointArr[i].y);
+	}
+	Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
+    }
+    sprintf(graphPtr->scratchPtr, "%d %d lineto\nDashesProc stroke\n",
+	pointArr[i].x, pointArr[i].y);
+    Tcl_AppendResult(graphPtr->interp, graphPtr->scratchPtr, (char *)NULL);
+}
 
 
+
 static void
 DestroyPostScript(graphPtr)
     Graph *graphPtr;
@@ -919,7 +975,6 @@ DestroyPostScript(graphPtr)
     free((char *)graphPtr->postscript);
 }
 
-
 /*
  *----------------------------------------------------------------------
  *
@@ -944,14 +999,14 @@ ConfigurePostScript(graphPtr, argc, argv)
     int flags = TK_CONFIG_ARGV_ONLY;
 
     if (argc == 2) {
-	return (Tk_ConfigureInfo(graphPtr->interp, graphPtr->tkwin, 
-	    configSpecs, (char *)graphPtr->postscript, (char *)NULL, flags));
+	return (Tk_ConfigureInfo(graphPtr->interp, graphPtr->tkwin,
+		configSpecs, (char *)graphPtr->postscript, (char *)NULL, flags));
     } else if (argc == 3) {
 	return (Tk_ConfigureInfo(graphPtr->interp, graphPtr->tkwin,
 		configSpecs, (char *)graphPtr->postscript, argv[2], flags));
     }
     if (Tk_ConfigureWidget(graphPtr->interp, graphPtr->tkwin, configSpecs,
-	  argc - 2, argv + 2, (char *)graphPtr->postscript, flags) != TCL_OK) {
+	    argc - 2, argv + 2, (char *)graphPtr->postscript, flags) != TCL_OK) {
 	return TCL_ERROR;
     }
     return TCL_OK;
@@ -1036,8 +1091,9 @@ PrintPreamble(graphPtr, fileName)
 	(char *)NULL);
 
     /* Find upper left coordinate of bounding box */
-    origin = Blt_TranslateBoxCoords(psPtr->x, psPtr->y, psPtr->width,
-	psPtr->height, psPtr->anchor);
+    origin = Blt_TranslateBoxCoords(psPtr->x, psPtr->y,
+	(unsigned int)psPtr->width, (unsigned int)psPtr->height,
+	psPtr->anchor);
     sprintf(graphPtr->scratchPtr, "%%%%BoundingBox:  %d %d %d %d\n",
 	origin.x, 792 - (psPtr->height + origin.y),	/* Lower left */
 	origin.x + psPtr->width, (792 - origin.y));
@@ -1057,9 +1113,9 @@ PrintPreamble(graphPtr, fileName)
     libDir = Tcl_GetVar(graphPtr->interp, "blt_library", TCL_GLOBAL_ONLY);
     if (libDir == NULL) {
 	Tcl_ResetResult(graphPtr->interp);
-	Tcl_AppendResult(graphPtr->interp, 
-		"couldn't find BLT library directory:",
-	        " blt_library variable doesn't exist", (char *)NULL);
+	Tcl_AppendResult(graphPtr->interp,
+	    "couldn't find BLT library directory:",
+	    " blt_library variable doesn't exist", (char *)NULL);
 	return TCL_ERROR;
     }
     sprintf(string, "%.350s/bltGraph.pro", libDir);
@@ -1160,7 +1216,7 @@ PrintExterior(graphPtr, regionPtr)
     int x, y;
     XRectangle rectArr[4];
     TextAttr textAttr;
-    int lineHeight;
+    GraphAxis *axisPtr;
 
     rectArr[0].x = rectArr[0].y = rectArr[3].x = rectArr[1].x = 0;
     rectArr[0].width = rectArr[3].width = graphPtr->width;
@@ -1185,43 +1241,29 @@ PrintExterior(graphPtr, regionPtr)
 	    regionPtr->y, regionPtr->width, regionPtr->height,
 	    graphPtr->intBWidth, graphPtr->intRelief);
     }
-    x = (graphPtr->extreme.x + graphPtr->origin.x) / 2;
-
+    /* Print legend if using default location */
+    if (graphPtr->legendPtr->useDefault) {
+	(*graphPtr->legendPtr->printProc) (graphPtr);
+    }
     textAttr.theta = 0.0;
     textAttr.anchor = TK_ANCHOR_CENTER;
     textAttr.fgColorPtr = graphPtr->fgColorPtr;
     textAttr.bgColorPtr = (XColor *)NULL;
     textAttr.fontPtr = graphPtr->fontPtr;
 
-    lineHeight = TEXTHEIGHT(graphPtr->fontPtr);
-    Blt_FontToPostScript(graphPtr, graphPtr->fontPtr);
-    Blt_ForegroundToPostScript(graphPtr, graphPtr->fgColorPtr);
     if (graphPtr->title != NULL) {
-	y = graphPtr->extBWidth + lineHeight;
+	x = (graphPtr->extreme.x + graphPtr->origin.x) / 2;
+	y = graphPtr->extBWidth + TEXTHEIGHT(graphPtr->fontPtr);
 	Blt_TextToPostScript(graphPtr, graphPtr->title, &textAttr, x, y);
     }
-    /* X Axis title */
-    if (graphPtr->xTitle != NULL) {
-	y = graphPtr->height - (graphPtr->extBWidth + lineHeight);
-	Blt_TextToPostScript(graphPtr, graphPtr->xTitle, &textAttr, x, y);
+    for (i = 0; i < 4; i++) {	/* Print axes */
+	axisPtr = graphPtr->axisArr[i];
+	if (axisPtr->mapped) {
+	    (*axisPtr->printProc) (graphPtr, axisPtr, &textAttr);
+	}
     }
-    /* Y Axis title */
-    if (graphPtr->yTitle != NULL) {
-	x = graphPtr->extBWidth + lineHeight;
-	y = (graphPtr->extreme.y + graphPtr->origin.y) / 2;
-	textAttr.theta = 90.0;
-	Blt_TextToPostScript(graphPtr, graphPtr->yTitle, &textAttr, x, y);
-    }
-    /* Print legend if using default location */
-    if (graphPtr->legendPtr->position.x == DEF_POSITION) {
-	(*graphPtr->legendPtr->printProc) (graphPtr);
-    }
-    /* Print axes */
-    (*graphPtr->X->printProc) (graphPtr);
-    (*graphPtr->Y->printProc) (graphPtr);
 }
 
-
 /*
  *----------------------------------------------------------------------
  *
@@ -1247,12 +1289,13 @@ PrintPostScript(graphPtr, argc, argv)
     GraphLegend *legendPtr = graphPtr->legendPtr;
     XRectangle clipRect;
     int result = TCL_ERROR;
-    char scratchSpace[BUFSIZ*2];
+    char scratchSpace[BUFSIZ * 2];
     FILE *f = NULL;
     int twiceBW;
     char *fileName;		/* Name of file to write PostScript output
                                  * If NULL, output is returned via
                                  * interp->result. */
+
     fileName = NULL;
     if ((argc > 2) && (argv[2][0] != '-')) {
 	f = fopen(argv[2], "w");
@@ -1267,8 +1310,8 @@ PrintPostScript(graphPtr, argc, argv)
     graphPtr->scratchPtr = scratchSpace;
     if ((argc > 0) &&
 	(Tk_ConfigureWidget(graphPtr->interp, graphPtr->tkwin, configSpecs,
-			    argc - 2, argv + 2, (char *)psPtr, 
-			    TK_CONFIG_ARGV_ONLY) != TCL_OK)) {
+		argc - 2, argv + 2, (char *)psPtr,
+		TK_CONFIG_ARGV_ONLY) != TCL_OK)) {
 	goto error;
     }
     /* Scale coordinates into printer points (pica) */
@@ -1316,12 +1359,12 @@ PrintPostScript(graphPtr, argc, argv)
     /*
      * Draw the elements and tags on the interior of the plotting surface
      */
-    if (legendPtr->position.x != DEF_POSITION) {
+    if (!legendPtr->useDefault) {
 	(*legendPtr->printProc) (graphPtr);
     }
-    /* If this is a graph, draw the elements on top of tags.  On barcharts, 
+    /* If this is a graph, draw the elements on top of tags.  On barcharts,
      * it's the opposite. */
-    if (graphPtr->type == GRAPH_TYPE) {
+    if (graphPtr->type == GRAPH) {
 	PrintTags(graphPtr);
 	PrintElements(graphPtr);
     } else {
@@ -1359,7 +1402,6 @@ PrintPostScript(graphPtr, argc, argv)
     return (result);
 }
 
-
 /*
  *----------------------------------------------------------------------
  *
