@@ -920,18 +920,18 @@ LayoutText(graphPtr, tagPtr)
     Tag *tagPtr;
 {
     TextTag *textTagPtr = (TextTag *)tagPtr;
-    XPoint win, textPos;
+    XPoint win, anchorPos;
 
     if (textTagPtr->text == NULL) {
 	return;
     }
     win = Blt_TransformPt(graphPtr, textTagPtr->coordArr[0],
 	textTagPtr->coordArr[1], textTagPtr->axisFlags);
-    textPos = Blt_TranslateTextCoords(textTagPtr->fontPtr, textTagPtr->text,
+    anchorPos = Blt_TranslateTextCoords(textTagPtr->fontPtr, textTagPtr->text,
 	win.x, win.y, textTagPtr->anchor);
     /* Save page coordinates */
-    textTagPtr->x = (textPos.x + textTagPtr->xOffset);
-    textTagPtr->y = (textPos.y + textTagPtr->yOffset);
+    textTagPtr->x = (anchorPos.x + textTagPtr->xOffset);
+    textTagPtr->y = (anchorPos.y + textTagPtr->yOffset);
 
     if (textTagPtr->bitmap != None) {
 	XFreePixmap(graphPtr->display, textTagPtr->bitmap);
@@ -946,10 +946,10 @@ LayoutText(graphPtr, tagPtr)
 	    Tk_WindowId(graphPtr->tkwin), textTagPtr->fontPtr,
 	    textTagPtr->text, textTagPtr->theta, &(textTagPtr->width),
 	    &(textTagPtr->height));
-	textPos = Blt_TranslateBoxCoords(win.x, win.y, textTagPtr->width,
+	anchorPos = Blt_TranslateBoxCoords(win.x, win.y, textTagPtr->width,
 	    textTagPtr->height, textTagPtr->anchor);
-	textTagPtr->x = textPos.x + textTagPtr->xOffset;
-	textTagPtr->y = textPos.y + textTagPtr->yOffset;
+	textTagPtr->x = anchorPos.x + textTagPtr->xOffset;
+	textTagPtr->y = anchorPos.y + textTagPtr->yOffset;
 	XSetStipple(graphPtr->display, textTagPtr->gc, textTagPtr->bitmap);
 	XSetTSOrigin(graphPtr->display, textTagPtr->gc, textTagPtr->x,
 	    textTagPtr->y);
@@ -1331,14 +1331,14 @@ LayoutWindow(graphPtr, tagPtr)
     WindowTag *winTagPtr = (WindowTag *)tagPtr;
 
     if (winTagPtr->child != (Tk_Window)NULL) {
-	XPoint win;		/* Calculated window coordinates of window */
+	XPoint anchorPos;	/* Calculated window coordinates of window */
 
-	win = Blt_TransformPt(graphPtr, winTagPtr->coordArr[0],
+	anchorPos = Blt_TransformPt(graphPtr, winTagPtr->coordArr[0],
 	    winTagPtr->coordArr[1], winTagPtr->axisFlags);
-	win = Blt_TranslateBoxCoords(win.x, win.y, winTagPtr->width,
-	    winTagPtr->height, winTagPtr->anchor);
-	winTagPtr->x = win.x + winTagPtr->xOffset;
-	winTagPtr->y = win.y + winTagPtr->yOffset;
+	anchorPos = Blt_TranslateBoxCoords(anchorPos.x, anchorPos.y, 
+	    winTagPtr->width, winTagPtr->height, winTagPtr->anchor);
+	winTagPtr->x = anchorPos.x + winTagPtr->xOffset;
+	winTagPtr->y = anchorPos.y + winTagPtr->yOffset;
     }
 }
 
@@ -1992,7 +1992,7 @@ GetTagCoords(interp, tagPtr, coordList)
     coordArr = NULL;
     if (numExprs > 0) {
 	if (numExprs & 1) {
-	    interp->result = "Odd number of tag coordinates specified";
+	    interp->result = "odd number of tag coordinates specified";
 	    goto error;
 	}
 	switch (tagPtr->type) {
@@ -2008,15 +2008,15 @@ GetTagCoords(interp, tagPtr, coordList)
 	    minArgs = 2, maxArgs = 2;
 	    break;
 	default:
-	    interp->result = "Unknown tag type";
+	    interp->result = "unknown tag type";
 	    goto error;
 	}
 	if (numExprs < minArgs) {
-	    interp->result = "Too few tag coordinates specified";
+	    interp->result = "too few tag coordinates specified";
 	    goto error;
 	}
 	if ((maxArgs > 0) && (numExprs > maxArgs)) {
-	    interp->result = "Too many tag coordinates specified";
+	    interp->result = "too many tag coordinates specified";
 	    goto error;
 	}
 	coordArr = (double *)malloc((unsigned int)numExprs * sizeof(double));
