@@ -33,22 +33,18 @@
 #include <limits.h>
 #endif
 
-/* math.h */
-
 /*
  * ----------------------------------------------------------------------
  *
- * 	MAX_DBL_VALUE and MIN_DBL_VALUE:
+ * MAX_DBL_VALUE and MIN_DBL_VALUE are the largest and small values
+ * representable on the graph or barchart.  They are used for the
+ * following:
  *
- *	There values are the largest and small values representable
- * 	on the graph or barchart.  They are used for the following
+ * 1. when searching for smallest or largest value of a set, 
+ *    initialize current min/max to this.  
  *
- *	1. when searching for smallest or largest value of a set,
- *	    initialize current min/max to this.
- *	2. represent tag coordinates "Inf" and "-Inf".
- *	3. uninitialized floating point values.
- *
- * ----------------------------------------------------------------------
+ * 2. represent tag coordinates "Inf" and "-Inf".  
+ * ---------------------------------------------------------------------- 
  */
 #ifdef HAVE_FLOAT_H
 #define MAX_DBL_VALUE 	DBL_MAX
@@ -85,18 +81,17 @@
 /*
  * ------------------------------------------------------------------------
  *
- * 	Replacement macros for math library functions, fabs, abs, rint,
- *	and exp10.
+ * Definitions of macros replacing math library functions, fabs, abs,
+ * rint, and exp10.
  *
- * 	Although many of these routines may be in the math library, they
- *	aren't used in libtcl.a or libtk.a.  This makes it impossible to
- *	load BLT library as a shared object without requiring that the
- *	math library be a shared object too.  Avoid the problem by
- *	replacing the "exotic" math routines with macros.
+ * Although many of these routines may be in your math library, they
+ * aren't used in libtcl.a or libtk.a.  This makes it impossible to
+ * load BLT library as a shared object without requiring that the math
+ * library be a shared object too.  We avoid the problem by replacing
+ * the "exotic" math routines with macros.
  *
- * ------------------------------------------------------------------------
+ * ------------------------------------------------------------------------ 
  */
-
 #undef FABS
 #define FABS(x)		(((x)<0.0)?(-(x)):(x))
 
@@ -125,39 +120,31 @@
 #define SHRT_MAX	0x7FFF
 #endif /* SHRT_MAX */
 
-#include "bltList.h"
-
 #define TRUE 1
 #define FALSE 0
 
 /*
- * Mask values used to selectively enable entries in the
- * configuration specs:
+ * Mask values used to selectively enable GRAPH or BARCHART entries in
+ * the various configuration specs.
  */
-
 #define XYGRAPH_MASK	TK_CONFIG_USER_BIT
 #define BARCHART_MASK	TK_CONFIG_USER_BIT << 1
-#define CONTOUR_MASK	TK_CONFIG_USER_BIT << 2
 #define ALL_MASK	(XYGRAPH_MASK | BARCHART_MASK)
-
-/*
- * NUMDIGITS specifies the number of digits accuracy used when
- * outputing data (e.g. axis tick labels, etc)
- */
-#define NUMDIGITS	12
+#define CONTOUR_MASK	TK_CONFIG_USER_BIT << 2
 
 #define PADX		2	/* Padding between labels/titles */
 #define PADY    	2	/* Padding between labels */
 #define TEXTHEIGHT(f) 	((f)->ascent + (f)->descent)
-
-#define DEF_POSITION -SHRT_MAX	/* Indicates that no position was specified */
+#define DEF_POSITION 	-SHRT_MAX   /* Indicates that no position was
+				     * specified */
 
 /*
  * -------------------------------------------------------------------
+ *
  * 	Graph component structure definitions
- * -------------------------------------------------------------------
+ *
+ * ------------------------------------------------------------------- 
  */
-
 typedef struct Graph Graph;
 typedef struct GraphAxis GraphAxis;
 typedef struct GraphLegend GraphLegend;
@@ -167,7 +154,7 @@ typedef struct GraphCrosshairs GraphCrosshairs;
 /*
  * -------------------------------------------------------------------
  *
- * 	GraphClassType --
+ * GraphClassType --
  *
  *	Enumerates the different types of graphs this program
  *	produces. Currently, only one this of graph is allowed
@@ -182,7 +169,7 @@ typedef enum {
 /*
  * -------------------------------------------------------------------
  *
- * 	TextAttr --
+ * TextAttr --
  *
  * 	Represents a convenience structure to hold text attributes
  *	which determine how a text string is to be displayed on the
@@ -197,16 +184,17 @@ typedef struct {
     XFontStruct *fontPtr;	/* Font to use for string */
     XColor *bgColorPtr;		/* Background color of string */
     XColor *fgColorPtr;		/* Foreground color of string */
-    Tk_Anchor anchor;		/* Anchor type: used to position the string */
+    Tk_Anchor anchor;		/* Anchor type: used to position the
+				 * string */
     double theta;		/* Rotation of text in degrees. */
-    GC gc;			/* Graphics context to use when displaying the
-				 * string on the window */
+    GC gc;			/* Graphics context to use when displaying
+				 * the string on the window */
 } TextAttr;
 
 /*
  * -------------------------------------------------------------------
  *
- * 	AxisTypes --
+ * AxisTypes --
  *
  *	Enumerated type representing the types of axes
  *
@@ -223,17 +211,11 @@ typedef enum AxisTypes {
 #define AXIS_X_MASK		(AXIS_X1_FLAG|AXIS_X2_FLAG)
 #define AXIS_Y_MASK		(AXIS_Y1_FLAG|AXIS_Y2_FLAG)
 #define AXIS_TYPE_MASK		(AXIS_Y_MASK|AXIS_X_MASK)
-#define AXIS_LIMIT_USER_BIT	0x10
-#define AXIS_LIMIT_MIN_MASK	(AXIS_LIMIT_USER_BIT << LMIN)
-#define AXIS_LIMIT_MAX_MASK	(AXIS_LIMIT_USER_BIT << LMAX)
-#define AXIS_LIMIT_MASK		(AXIS_LIMIT_MIN_MASK | AXIS_LIMIT_MAX_MASK)
-#define AXIS_MIN_AUTOSCALE(a) 	(((a)->flags & AXIS_LIMIT_MIN_MASK)==0)
-#define AXIS_MAX_AUTOSCALE(a) 	(((a)->flags & AXIS_LIMIT_MAX_MASK)==0)
 
 /*
  * -------------------------------------------------------------------
  *
- * 	GraphAxis --
+ * GraphAxis --
  *
  * 	Structure contains options controlling how the axis will be
  * 	displayed.
@@ -248,7 +230,8 @@ typedef void (AxisDestroyProc) _ANSI_ARGS_((Graph *, GraphAxis *));
 
 struct GraphAxis {
     unsigned int flags;		/* Axis flags */
-    int logScale;		/* If non-zero, scale values logarithmically */
+    int logScale;		/* If non-zero, scale values
+				 * logarithmically */
     int mapped;			/* If non-zero, display the axis */
 
     AxisDisplayProc *displayProc;
@@ -260,7 +243,7 @@ struct GraphAxis {
 /*
  * -------------------------------------------------------------------
  *
- * 	GraphLegend --
+ * GraphLegend --
  *
  * 	Contains information specific to how the legend will be
  *	displayed.
@@ -274,14 +257,13 @@ typedef void (LegendDestroyProc) _ANSI_ARGS_((Graph *));
 typedef int (LegendGeometryProc) _ANSI_ARGS_((Graph *));
 
 struct GraphLegend {
-    int mapped;			/* Requested state of the legend, If non-zero,
-				 * legend is displayed */
+    int mapped;			/* Requested state of the legend, If
+				 * non-zero, legend is displayed */
     int width, height;		/* Dimensions of the legend */
-    XPoint anchorPos;		/* Window coordinates of legend positioning
-				 * point. Used in conjunction with the anchor
-				 * to determine the location of the legend. If
-				 * x or y are DEF_POSITION the legend is set
-				 * in the right margin */
+    XPoint anchorPos;		/* Window coordinates of legend
+				 * positioning point. Used in conjunction
+				 * with the anchor to determine the
+				 * location of the legend. */
     int useDefault;		/* Draw the legend in the default location */
 
     LegendDisplayProc *displayProc;
@@ -293,7 +275,7 @@ struct GraphLegend {
 /*
  * -------------------------------------------------------------------
  *
- * 	GraphPostScript --
+ * GraphPostScript --
  *
  * 	Structure contains information specific to the outputing of
  *	PostScript commands to print the graph.
@@ -314,7 +296,7 @@ struct GraphPostScript {
 /*
  * -------------------------------------------------------------------
  *
- * 	GraphCrosshairs --
+ * GraphCrosshairs --
  *
  *	Contains the line segments positions and graphics context used
  *	to simulate crosshairs (by XORing) on the graph.
@@ -327,19 +309,16 @@ typedef void (CrosshairsConfigProc) _ANSI_ARGS_((Graph *));
 typedef void (CrosshairsDestroyProc) _ANSI_ARGS_((Graph *));
 
 struct GraphCrosshairs {
-
     CrosshairsToggleProc *toggleProc;	/* Toggle visiblity of crosshairs */
     CrosshairsUpdateProc *updateProc;	/* Update lengths of hairs */
     CrosshairsConfigProc *configProc;	/* Configure GC */
     CrosshairsDestroyProc *destroyProc;	/* Release X resources */
-
-
 };
 
 /*
  * -------------------------------------------------------------------
  *
- * 	Graph --
+ * Graph --
  *
  *	Top level structure containing everything pertaining to
  *	the graph.
@@ -347,18 +326,21 @@ struct GraphCrosshairs {
  * -------------------------------------------------------------------
  */
 struct Graph {
-    Tk_Window tkwin;		/* Window that embodies the graph.  NULL means
-				 * that the window has been destroyed but the
-				 * data structures haven't yet been cleaned
-				 * up. */
+    Tk_Window tkwin;		/* Window that embodies the graph.  NULL
+				 * means that the window has been
+				 * destroyed but the data structures
+				 * haven't yet been cleaned up. */
     Pixmap canvas;		/* Pixmap for double buffering output */
-    Display *display;		/* Display containing widget;  needed, among
-				 * other things, to release resources after
-				 * tkwin has already gone away. */
-    char *pathName;		/* Pathname of the widget. Is saved here in
-				 * case the widget is destroyed and tkwin
-				 * become unavailable for querying */
-    Tcl_Interp *interp;		/* Interpreter associated with graph widget */
+    Display *display;		/* Display containing widget; needed,
+				 * among other things, to release
+				 * resources after tkwin has already gone
+				 * away. */
+    char *pathName;		/* Pathname of the widget. Is saved here
+				 * in case the widget is destroyed and
+				 * tkwin become unavailable for querying
+				 * */
+    Tcl_Interp *interp;		/* Interpreter associated with graph
+				 * widget */
     GraphClassType type;	/* Type: either GRAPH or BARCHART */
     unsigned int flags;		/* Flags;  see below for definitions. */
     int reqWidth, reqHeight;	/* Requested size of graph window */
@@ -370,12 +352,14 @@ struct Graph {
     GraphPostScript *postscript;/* PostScript options: see bltGrPS.c */
     GraphLegend *legendPtr;	/* Legend information: see bltGrLegd.c */
     GraphAxis *axisArr[4];	/* Coordinate axis info: see bltGrAxis.c */
-    GraphCrosshairs *crosshairs;/* Crosshairs information: see bltGrHairs.c */
+    GraphCrosshairs *crosshairs;/* Crosshairs information: see
+				   bltGrHairs.c */
 
-    char *scratchPtr;		/* Utility space for building strings. Points
-				 * to buffer of BUFSIZ bytes on the stack.
-				 * Currently used to create PostScript output
-				 * for the "postscript" command. */
+    char *scratchPtr;		/* Utility space for building strings.
+				 * Points to buffer of BUFSIZ bytes on
+				 * the stack.  Currently used to create
+				 * PostScript output for the
+				 * "postscript" command. */
 
     int leftMargin;		/* Requested sizes for margins surrounding */
     int rightMargin;		/* the plotting area. If non-zero, the */
@@ -404,11 +388,13 @@ struct Graph {
     char *title;		/* Graph title */
 
     XFontStruct *fontPtr;	/* Font for title and axis labels */
-    XColor *fgColorPtr;		/* Foreground color of title and axis labels */
+    XColor *fgColorPtr;		/* Foreground color of title and axis
+				 * labels */
     Cursor cursor;
 
-    Tcl_HashTable elemTable;	/* Hash table containing all elements created,
-				 * not just those currently displayed. */
+    Tcl_HashTable elemTable;	/* Hash table containing all elements
+				 * created, not just those currently
+				 * displayed. */
     Blt_LinkedList elemList;	/* Display list of elements */
     Tcl_HashTable tagTable;	/* Hash table of tags */
     Blt_LinkedList tagList;	/* Display list of tags */
@@ -418,37 +404,41 @@ struct Graph {
 
 /*
  * Flag bits for graphs:
- *
- * REDRAW_PENDING:		Non-zero means a DoWhenIdle handler has
- *				already been queued to redraw this window.
- *
- * REDRAW_ALL:		        Non-zero means that exterior region of the
- *				graph, in addition to the interior (plotting
- *				surface) needs to be redrawn. The possible
- *				reasons are: 1) an axis configuration changed
- *				2) an axis limit changed 3) titles have changed
- *				4) window was resized.
- *
- * LAYOUT_PENDING:		Non-zero means that a graph configuration
- *				has changed (element, tag, axis, legend, etc)
- *				and the layout of the graph (position of the
- *				graph in the window) needs to be recalculated.
- *
- * LAYOUT_ALL:		        Non-zero indicates that the layout of the axes
- *				and all elements and tags need to be
- *				recalculated.  Otherwise, the layout routines
- *				will recompute the layout of only those tags
- *				and elements that have changed.
- *
  */
-#define REDRAW_PENDING		(1<<0)
-#define REDRAW_ALL		(1<<1)
-#define LAYOUT_PENDING	        (1<<2)
-#define LAYOUT_ALL		(1<<3)
+
+#define REDRAW_PENDING 	(1<<0)	  /* Non-zero means a DoWhenIdle
+				 * handler has already been queued to
+				 * redraw this window. */
+#define REDRAW_ALL	(1<<1)   /* Non-zero means that exterior
+				 * region of the graph, in addition to
+				 * the interior (plotting surface)
+				 * needs to be redrawn. The possible
+				 * reasons are:
+				 * 
+				 * 1) an axis configuration changed 
+				 *
+				 * 2) an axis limit changed 
+				 *
+				 * 3) titles have changed 
+				 *
+				 * 4) window was resized. 
+				 */
+#define	LAYOUT_PENDING 	(1<<2)	  /* Non-zero means that a graph
+				 * configuration has changed (element,
+				 * tag, axis, legend, etc) and the
+				 * layout of the graph (position of
+				 * the graph in the window) needs to
+				 * be recalculated. */
+#define	LAYOUT_ALL 	(1<<3)   /* Non-zero indicates that the layout
+				 * of the axes and all elements and
+				 * tags need to be recalculated.
+				 * Otherwise, the layout routines will
+				 * recompute the layout of only those
+				 * tags and elements that have
+				 * changed. */
 
 /*
- * ---------------------- Forward declarations ------------------------
- */
+ * ---------------------- Forward declarations ------------------------ */
 extern Pixmap Blt_CreateTextBitmap _ANSI_ARGS_((Display * display,
 	Drawable draw, XFontStruct *fontPtr, char *textStr, double theta,
 	unsigned int *bmWPtr, unsigned int *bmHPtr));
