@@ -23,6 +23,10 @@
 
 #include <tcl.h>
 
+#ifndef BLT_VERSION
+#define BLT_VERSION "1.3"
+#endif
+
 /*
  * The inclusion of contributed commands/widgets can be suppressed by
  * defining the respective preprocessor symbol.
@@ -30,51 +34,39 @@
 
 #ifndef NO_HTEXT
 EXTERN int Blt_HtextInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_GRAPH
 EXTERN int Blt_GraphInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_BARCHART
 EXTERN int Blt_BarchartInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_TABLE
 EXTERN int Blt_TableInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_BUSY
 EXTERN int Blt_BusyInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_WINDOW
 EXTERN int Blt_WindowInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_BITMAP
 EXTERN int Blt_BitmapInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_BGEXEC
 EXTERN int Blt_BgExecInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_DRAGDROP
 EXTERN int Blt_DragDropInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_DEBUG
 EXTERN int Blt_DebugInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_BELL
 EXTERN int Blt_BellInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 #ifndef NO_CUTBUFFER
 EXTERN int Blt_CutbufferInit _ANSI_ARGS_((Tcl_Interp *interp));
-
 #endif
 
 int
@@ -89,6 +81,7 @@ Blt_Init(interp)
     }
     Tcl_SetVar2(interp, "blt_library", (char *)NULL, libDir, TCL_GLOBAL_ONLY);
 
+
 #ifndef NO_HTEXT
     if (Blt_HtextInit(interp) != TCL_OK) {
 	return TCL_ERROR;
@@ -149,5 +142,6 @@ Blt_Init(interp)
 	return TCL_ERROR;
     }
 #endif
+    Tcl_SetVar2(interp, "blt_versions", "BLT", BLT_VERSION, TCL_GLOBAL_ONLY);
     return TCL_OK;
 }
